-- Title: iLvLr
-- Author: JerichoHM
-- Version: 1.0.210
-- Desc: iLvL identifier

-- GetItemInfo
-- Frame/CreateFontString
-- FontString
-- UNIT_INVENTORY_CHANGED

--Version Information
local Title = "iLvLr"
local Core = "1"
local Revision = "0"
local Build = "210"

local frameDB = {CharacterHeadSlot,
					CharacterNeckSlot,
					CharacterShoulderSlot,
					CharacterBackSlot,
					CharacterChestSlot,
					CharacterWristSlot,
					CharacterShirtSlot,
					CharacterTabardSlot,
					CharacterMainHandSlot,
					CharacterSecondaryHandSlot,
					CharacterRangedSlot,
					CharacterHandsSlot,
					CharacterWaistSlot,
					CharacterLegsSlot,
					CharacterFeetSlot,
					CharacterFinger0Slot,
					CharacterFinger1Slot,
					CharacterTrinket0Slot,
					CharacterTrinket1Slot
				}

local slotDB = {"HeadSlot",
					"NeckSlot",
					"ShoulderSlot",
					"BackSlot",
					"ChestSlot",
					"WristSlot",
					"ShirtSlot",
					"TabardSlot",
					"MainHandSlot",
					"SecondaryHandSlot",
					"RangedSlot",
					"HandsSlot",
					"WaistSlot",
					"LegsSlot",
					"FeetSlot",
					"Finger0Slot",
					"Finger1Slot",
					"Trinket0Slot",
					"Trinket1Slot"
				}

local iQualityFrames = {}
				
function iLvLrMain()
	iLvLrFrame = CreateFrame("Frame", "iLvLrFrame", UIParent)

	iLvLrFrame:RegisterEvent("ADDON_LOADED")
	iLvLrFrame:RegisterEvent("UNIT_INVENTORY_CHANGED")
	iLvLrFrame:SetScript("OnEvent", iLvLrOnEvent)
end

function iLvLrOnLoad()
	for k ,v in pairs(slotDB) do
		local iLevel = fetchIlvl(v)
		if iLevel then
			makeText(frameDB[k])
			makeQuality(frameDB[k], v)
			if v == "ShirtSlot" or v == "TabardSlot" then
				frameDB[k].text:SetFormattedText("", iLevel)
			else
				frameDB[k].text:SetFormattedText("|cFFFFFF00%i", iLevel)
			end
		end
	end
end

function iLvLrOnUpdate()
	for k ,v in pairs(slotDB) do
		local iLevel = fetchIlvl(v)
		if iLevel then
			if not frameDB[k].text then
				makeText(frameDB[k])
			end
			makeQuality(frameDB[k], v)
			if v == "ShirtSlot" or v == "TabardSlot" then
				frameDB[k].text:SetFormattedText("", iLevel)
			else
				frameDB[k].text:SetFormattedText("|cFFFFFF00%i", iLevel)
			end
		else
			if frameDB[k].text then
				frameDB[k].text:SetFormattedText("")
			end
			if iQualityFrames[v] then
				iQualityFrames[v]:Hide()
			end
		end
	end
end

function iLvLrOnEvent(self, event, arg1)
	if event == "ADDON_LOADED" and arg1 == "iLvLr" then
		iLvLrOnLoad()
	elseif event == "UNIT_INVENTORY_CHANGED" then
		iLvLrOnUpdate()
	end
end

function fetchIlvl(slotName)
	local slotId, texture, checkRelic = GetInventorySlotInfo(slotName)
	local itemId = GetInventoryItemID("player", slotId)
	if itemId then
		local name, link, quality, iLevel, reqLevel, class, subclass, maxStack, equipSlot, texture, vendorPrice = GetItemInfo(itemId)
		return(iLevel)
	end
end

function fetchQuality(slotName)
	local slotId, texture, checkRelic = GetInventorySlotInfo(slotName)
	local itemId = GetInventoryItemID("player", slotId)
	if itemId then
		local name, link, quality, iLevel, reqLevel, class, subclass, maxStack, equipSlot, texture, vendorPrice = GetItemInfo(itemId)
		local r, g, b, hex = GetItemQualityColor(quality)
		return r, g, b
	end
end

function makeText(frame)
	local ilvlText = frame:CreateFontString(nil, "ARTWORK")
	isValid = ilvlText:SetFont("Fonts\\FRIZQT__.TTF", 12)
	
	if frame == CharacterHeadSlot or frame == CharacterNeckSlot or frame == CharacterShoulderSlot or frame == CharacterBackSlot or frame == CharacterChestSlot or frame == CharacterWristSlot or frame == CharacterShirtSlot or frame == CharacterTabardSlot then
		ilvlText:SetPoint("CENTER", frame, "CENTER", 40, 0)
	elseif frame == CharacterHandsSlot or frame == CharacterWaistSlot or frame == CharacterLegsSlot or frame == CharacterFeetSlot or frame == CharacterFinger0Slot or frame == CharacterFinger1Slot or frame == CharacterTrinket0Slot or frame == CharacterTrinket1Slot then
		ilvlText:SetPoint("CENTER", frame, "CENTER", -40, 0)
	elseif frame == CharacterMainHandSlot or frame == CharacterSecondaryHandSlot or frame == CharacterRangedSlot then
		ilvlText:SetPoint("CENTER", frame, "CENTER", 0, 30)
	end
	
	frame.text = ilvlText
end

function makeQuality(frame, slot)
	local iQuality = iQualityFrames[slot]
	if not iQuality then
		iQuality = CreateFrame("Frame", nil, frame)
		iQuality:SetPoint("CENTER", frame, "CENTER", 0, 0)
		iQuality:SetWidth(frame:GetWidth())
		iQuality:SetHeight(frame:GetHeight())
		iQuality:SetBackdrop({bgFile = nil, edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border.blp", tile = true, tileSize = 32, edgeSize = 16, insets = {left = 0, right = 0, top = 0, bottom = 0}})
		
		local r, g, b = fetchQuality(slot)
		iQuality:SetBackdropBorderColor(r, g, b, 1.0)
		
		iQualityFrames[slot] = iQuality
	else
		local r, g, b = fetchQuality(slot)
		iQuality:SetBackdropBorderColor(r, g, b, 1.0)
	end
	
	iQuality:Show()
end

iLvLrMain()